@@ -5,9 +5,11 @@ word_regexes = {
     'uk': r'[АаБбВвГгҐґДдЕеЄєЖжЗзИиІіЇїЙйКкЛлМмНнОоПпРрСсТтУуФфХхЦцЧчШшЩщЬЮюЯя]+',
     'tr': r'[a-zA-ZçÇğĞüÜöÖşŞıİ]+',
     'es': r'[A-Za-zÁáÉéÍíÓóÚúÜüÑñ]+',
+    'pt': r'[a-zA-ZãáàâçéêíõóôúüÃÁÀÂÇÉÊÍÕÓÔÚÜ]+',
     'cs': r'[AÁBCČDĎEÉĚFGH(Ch)IÍJKLMNŇOÓPQRŘSŠTŤUÚŮVWXYÝZŽaábcčdďeéěfgh(ch)iíjklmnňoópqrřsštťuúůvwxyýzž]+',
 }
 
+
 alphabets = {
     'en': 'abcdefghijklmnopqrstuvwxyz',
     'pl': 'abcdefghijklmnopqrstuvwxyzęóąśłżźćń',
@@ -15,27 +17,15 @@ alphabets = {
     'uk': 'фагксщроємшплуьцнжхїйювязтибґідеч',
     'tr': 'abcçdefgğhıijklmnoöprsştuüvyzqwxÇĞİÜÖ',
     'es': 'abcdefghijklmnopqrstuvwxyzáéíóúüñ',
+    'pt': 'abcdefghijklmnopqrstuvwxyzãáàâçéêíõóôúü',
     'cs': 'aábcčdďeéěfgh(ch)iíjklmnňoópqrřsštťuúůvwxyýzž',
 }
 
-# urls = {
-#     'en': 'https://drive.google.com/uc?export=download&id=19xqFyk9d8mFR7LR43oy6cExk8Pk9wVwV',
-#     'pl': 'https://drive.google.com/uc?export=download&id=1kqGWZLUsE8YAB-_nvfMJXNTjYBsjIvSN',
-#     'ru': 'https://drive.google.com/uc?export=download&id=1vvOako2MwtexEHX24Jx5CjjN-1yEXOrf',
-#     'uk': 'https://drive.google.com/uc?export=download&id=1nG_DG6aWU1PUA_DPSfrvh92puTLr8-aA',
-#     'tr': 'https://drive.google.com/uc?export=download&id=1ZGQEhLTteTQprRpnKrHTFWeV2RxYny21',
-#     'es': 'https://drive.google.com/uc?export=download&id=19VQuOE12sb0p10SBKWRbSdnUvk0eeFPg',
-# }
-
 urls = {
     'en': [
-        'https://dl.dropboxusercontent.com/s/jyyuqrtcbusw1kq/en.tar.gz?dl=0',
-        'https://dl.dropboxusercontent.com/s/cz6koxli82rqdia/en.tar.gz?dl=0',
-        'https://siasky.net/_AqMToyBioTOgKzTHwCsurBfeOwq4XGbV38ryEXwR_ULQA'],
+        'https://dl.dropboxusercontent.com/s/grxjmtw4db814g1/en.tar.gz?dl=0'],
     'pl': [
-        'https://dl.dropboxusercontent.com/s/7izndbb0buoufcg/pl.tar.gz?dl=0',
-        'https://dl.dropboxusercontent.com/s/3nfolvuz7clzuz4/pl.tar.gz?dl=0',
-        'https://siasky.net/AAC52kUAAmfZF_DUZVMQWWO-tJ3g3_3FDEhR2BUXr4oq8Q'],
+        'https://dl.dropboxusercontent.com/s/40orabi1l3dfqpp/pl.tar.gz?dl=0'],
     'ru': [
         'https://dl.dropboxusercontent.com/s/mpas7xqn8yl3wej/ru.tar.gz?dl=0',
         'https://dl.dropboxusercontent.com/s/6tzfxy34xx34mm7/ru.tar.gz?dl=0',
@@ -56,4 +46,7 @@ urls = {
         'https://dl.dropboxusercontent.com/s/8ptuuh8kcr3kufy/cs.tar.gz?dl=0',
         'https://dl.dropboxusercontent.com/s/369wplqb0w2ax21/cs.tar.gz?dl=0',
         'https://siasky.net/AAC6lW1ShlSRUeiFnr4_2bmw6sznlZsWvmhDhyQy_-g2wA'],
+    'pt': [
+        'https://dl.dropboxusercontent.com/s/6xnko882tsjgeaw/pt.tar.gz?dl=0',
+        'https://siasky.net/PAOmY66v3ggXpqNtbHQU_hb7ARNOL_Lv3LcTwFMMWmdzVw'],
 }
